// loading the csv dataset via url created in the github gist
const csvUrl =
  'https://gist.githubusercontent.com/bhargavikondaveeti/165d04c2e06c2d10544ac0a43ec2858a/raw/f76a0d624b03cb7228002baf17dfb61efa248c4f/Question-2_Dataset.csv';

d3.csv(csvUrl)
  .then((data) => {
    // Parsing the data
    data.forEach((d) => {
      d.label = +d.label;
      d.students = +d.students;
    });

    // creating the svg setup
    const svgWidth = 840;
    const svgHeight = 420;
    const margin = {
      top: 20,
      right: 20,
      bottom: 50,
      left: 50,
    };
    const width = svgWidth - margin.left - margin.right;
    const height = svgHeight - margin.top - margin.bottom;

    //providing the svg to the chart
    const svg = d3
      .select('#chart-container')
      .append('svg')
      .attr('width', svgWidth)
      .attr('height', svgHeight)
      .append('g')
      .attr(
        'transform',
        `translate(${margin.left},${margin.top})`,
      );

    //giving scale to x axis
    const xScale = d3
      .scaleLinear()
      .domain(d3.extent(data, (d) => d.label))
      .range([0, width]);

    //giving scale to y axis
    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.students)])
      .range([height, 0]);

    //generating the area under the curve for the linechart
    const area = d3
      .area()
      .x((d) => xScale(d.label))
      .y0(height)
      .y1((d) => yScale(d.students));

    //defining the gradient
    const gradient = svg
      .append('linearGradient')
      .attr('id', 'area-gradient')
      .attr('gradientUnits', 'userSpaceOnUse')
      .attr('x1', 0)
      .attr('y1', yScale(0))
      .attr('x2', 0)
      .attr('y2', yScale(d3.max(data, (d) => d.students)))
      .selectAll('stop')
      .data([
        { offset: '0%', color: 'rgba(150, 130, 180, 0.7)' },
        { offset: '100%', color: 'rgba(150, 130, 180, 0)' },
      ])
      .enter()
      .append('stop')
      .attr('offset', (d) => d.offset)
      .attr('stop-color', (d) => d.color);

    // assigning the gradient to the area chart
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'url(#area-gradient)')
      .attr('d', area);

    svg
      .append('g')
      .attr('transform', `translate(0, ${height})`)
      .call(d3.axisBottom(xScale));

    svg.append('g').call(d3.axisLeft(yScale));

    // giving label to x axis
    svg
      .append('text')
      .attr(
        'transform',
        `translate(${width / 2},${height + margin.bottom - 10})`,
      )
      .style('text-anchor', 'middle')
      .text('Marks Scored');

    // giving label to y aixs
    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Number of Students');
  })
  .catch((error) => {
    console.error('Error loading data:', error);
  });
